var thfaqf_settings = (function ($, window, document){
    'use strict';

    $(function () {
        var wrapper = $("#thfaqf_faq_form");
        var new_faq_from = $("#thfaqf_new_faq_form").html();

        $("body.post-type-faq #publish").click(function(event){
            var valid = validate_faq_post();
            return valid;
        });

        setup_sortable_meta_box();
        init_general_settings();
        init_faq_settings();
    });
     
    function setup_sortable_meta_box(){
        $(".meta-box-sortables")
        .sortable('option', 'cancel', '#thfaq_faq_list .hndle, :input, button')
        .sortable('refresh');
    }

    function init_general_settings(){
        var wrapper = $('#general_settings_form');

        setup_enhanced_multi_select(wrapper);
        setup_color_picker(wrapper);

        var enable_share_btn = wrapper.find('input[name="enable_share_button"]');
        enable_disble_social_share(enable_share_btn);
    }

    function init_faq_settings(){
        var wrapper = $('#thfaqf_faq_form');
        var wrapper_settings = $('#thfaqf-override-settings-panel');

        setup_color_picker(wrapper_settings);
        enable_disable_override_global_settings('#override_global_settings');
        setup_realtime_title_display(wrapper);        
    }

    function edit_faq_item(elm){
        var faq_item = $(elm).closest('.thfaqf-single-form-wrapper');
        var other_faq_items = faq_item.siblings('.thfaqf-single-form-wrapper');

        other_faq_items.removeClass("thfaqf-active");
        faq_item.toggleClass("thfaqf-active");
    }

    function delete_faq_item(elm){
        if(confirm('Are you sure you want to detete this FAQ?') == true){
            $(elm).closest('.thfaqf-single-form-wrapper').remove(); 
        }
    }

    function add_faq_item(elm){
        var wrapper = $("#thfaqf_faq_form");
        var faq_items = wrapper.find('.thfaqf-single-form-wrapper');
        faq_items.removeClass("thfaqf-active");
        var index = faq_items.length+1;
        var new_faq_from = $('#thfaqf_new_faq_form').html();
        wrapper.append(new_faq_from);

        setup_realtime_title_display(wrapper);
    }

    function insert_media(elm, event){
        event.preventDefault();

        var container = $(elm).siblings('.faq-input-content')
        var attachments = [];

        var frame = wp.media({
            title: 'Add Media',
            multiple: true 
        });

        frame.on('select', function(){
            attachments = frame.state().get('selection').map(function( attachment ){
                attachment.toJSON();
                return attachment;
            });

            var img_html = '';
            if(!$.isEmptyObject(attachments)){
                $.each(attachments, function(key, value){
                    img_html += '<img src="'+ value.attributes.url +'">';
                });
            }

            var content = container.val();
            content = content ? content+img_html : img_html;
            container.val(content);
        });

        frame.open();
    }

    function setup_realtime_title_display(wrapper){
        wrapper.find(".faq-input-title").keyup(function(event) {
            var value = this.value;
            $(this).closest('.thfaqf-single-form-wrapper').find('.faq-title').text(value); 
        });
    }

    function setup_enhanced_multi_select(wrapper){
        wrapper.find('select.thpladmin-enhanced-multi-select').select2();
    }

    function setup_color_pick_preview(wrapper){
        wrapper.find('.thpladmin-colorpicker').each(function(){
            $(this).parent().find('.thpladmin-colorpicker-preview').css({ backgroundColor: this.value });
        });
    }
    function setup_color_picker(wrapper){
        wrapper.find('.thpladmin-colorpicker').iris({
            change: function( event, ui ) {
                $( this ).parent().find( '.thpladmin-colorpicker-preview' ).css({ backgroundColor: ui.color.toString() });
            },
            hide: true,
            border: true,
        }).click( function() {
            $('.iris-picker').hide();
            $(this ).closest('td').find('.iris-picker').show();
        });
    
        $('body').click( function() {
            $('.iris-picker').hide();
        });
    
        $('.thpladmin-colorpicker').click( function( event ) {
            event.stopPropagation();
        });
    }

    function enable_disble_social_share(elm){
        var wrapper = $('#general_settings_form');

        if($(elm).is(":checked")){
            wrapper.find('.social-share-field').prop("readonly", false);
            wrapper.find('.social-share-field-multiselect').select2({disabled:false});
        }else{
            wrapper.find('.social-share-field').prop("readonly", true);
            wrapper.find('.social-share-field-multiselect').select2({disabled:true});
        }
    }

    function enable_disable_override_global_settings(elm){
        var wrapper = $('#thfaqf-override-settings-panel');
        wrapper.removeClass('thfaqf-disabled-panel');

        if($(elm).is(":checked")){
            wrapper.find('.thfaqf-override-field').prop("readonly", false);
        }else{
            wrapper.find('.thfaqf-override-field').prop("readonly", true);
            wrapper.addClass('thfaqf-disabled-panel');
        }
    }

    function copy_text(elm){
        var copy_text = document.getElementById("copy_to_clipboard");
        copy_text.select();
        document.execCommand("copy");
    }

    function validate_faq_post(){
        var valid = true;
        var faq_titles = $("#post #thfaqf_faq_form .faq-input-title");

        if(!faq_titles.length){
            alert('FAQ Post cannot be saved without at least one FAQ thread.');
            return false;
        }

        faq_titles.each(function(){
            if(!this.value){
                valid = false;
                return false;
            }
        });

        if(!valid){
            alert('FAQ cannot be saved without Title. Please enter a title for FAQ');
        }
        return valid;
    }

    return {
        addFaqItem : add_faq_item,
        editFaqItem : edit_faq_item,
        deleteFaqItem : delete_faq_item,
        insertMedia : insert_media,
        copyText : copy_text,
        enableDisableOverrideSettings : enable_disable_override_global_settings,
        enableDisbleSocialShare : enable_disble_social_share,
    }
}(window.jQuery, window, document));

function thfaqfAddFaqItem(elm){
    thfaqf_settings.addFaqItem(elm);
}

function thfaqfEditFaqItem(elm){
    thfaqf_settings.editFaqItem(elm);
}

function thfaqfDeleteFaqItem(elm){
    thfaqf_settings.deleteFaqItem(elm);
}

function thfaqfInsertMedia(elm, event){
    thfaqf_settings.insertMedia(elm, event);
}

function thfaqfCopyText(elm){
    thfaqf_settings.copyText(elm);
}

function thfaqfEnableDisableOverrideSettings(elm){
    thfaqf_settings.enableDisableOverrideSettings(elm);
}

function thfaqfEnableDisableSocialShare(elm){
    thfaqf_settings.enableDisbleSocialShare(elm);
}
